<?php
/**
 * Migration file for installing the Custom 404 Page extension.
 *
 * @package mundophpbb\custom404\migrations
 * @license http://opensource.org/licenses/gpl-2.0.php GNU General Public License v2
 */

namespace mundophpbb\custom404\migrations;

use phpbb\db\migration\migration;

class install_custom404 extends migration
{
    public function effectively_installed()
    {
        return $this->config->offsetExists('custom404_enabled');
    }

    public static function depends_on()
    {
        return ['\phpbb\db\migration\data\v32x\v321'];
    }

    public function update_data()
    {
        return [
            // Add configuration settings
            ['config.add', ['custom404_enabled', 1]],
            ['config.add', ['custom404_title', '404 Não Encontrado']],
            ['config.add', ['custom404_message', 'A página que você está procurando não foi encontrada.']],
            ['config.add', ['custom404_image_alt', 'Imagem de Erro 404']],
            ['config.add', ['custom404_image_path', 'ext/mundophpbb/custom404/styles/all/theme/images/404_error.png']],
            // Add the ACP module
            ['module.add', [
                'acp',
                'ACP_CAT_DOT_MODS',
                [
                    'module_basename' => '\mundophpbb\custom404\acp\main_module',
                    'module_langname' => 'ACP_CUSTOM404_SETTINGS',
                    'module_mode'     => 'settings',
                    'module_auth'     => 'ext_mundophpbb/custom404 && acl_a_board',
                ],
            ]],
        ];
    }

    public function revert_data()
    {
        return [
            // Remove the ACP module
            ['module.remove', [
                'acp',
                'ACP_CAT_DOT_MODS',
                'ACP_CUSTOM404_SETTINGS',
            ]],
            // Remove configuration settings
            ['config.remove', ['custom404_enabled']],
            ['config.remove', ['custom404_title']],
            ['config.remove', ['custom404_message']],
            ['config.remove', ['custom404_image_alt']],
            ['config.remove', ['custom404_image_path']],
        ];
    }
}